@@ -31,10 +31,10 @@ extern "C"
 #include <unistd.h>		/* ssize_t */
 #include <idn-int.h>		/* uint32_t */
 
-#define STRINGPREP_VERSION "0.2.3"
+#define STRINGPREP_VERSION "0.3.1"
 
 /* Error codes. */
-  enum Stringprep_rc
+  typedef enum
   {
     STRINGPREP_OK = 0,
     /* Stringprep errors. */
@@ -51,18 +51,18 @@ extern "C"
     /* Internal errors. */
     STRINGPREP_NFKC_FAILED = 200,
     STRINGPREP_MALLOC_ERROR = 201
-  };
+  } Stringprep_rc;
 
 /* Flags used when calling stringprep(). */
-  enum Stringprep_profile_flags
+  typedef enum
   {
     STRINGPREP_NO_NFKC = 1,
     STRINGPREP_NO_BIDI = 2,
     STRINGPREP_NO_UNASSIGNED = 4
-  };
+  } Stringprep_profile_flags;
 
 /* Steps in a stringprep profile. */
-  enum Stringprep_profile_steps
+  typedef enum
   {
     STRINGPREP_NFKC = 1,
     STRINGPREP_BIDI = 2,
@@ -72,7 +72,7 @@ extern "C"
     STRINGPREP_BIDI_PROHIBIT_TABLE = 6,
     STRINGPREP_BIDI_RAL_TABLE = 7,
     STRINGPREP_BIDI_L_TABLE = 8
-  };
+  } Stringprep_profile_steps;
 
 #define STRINGPREP_MAX_MAP_CHARS 4
 
@@ -86,8 +86,8 @@ extern "C"
 
   struct Stringprep_table
   {
-    enum Stringprep_profile_steps operation;
-    enum Stringprep_profile_flags flags;
+    Stringprep_profile_steps operation;
+    Stringprep_profile_flags flags;
     Stringprep_table_element *table;
     char *name;
   };
@@ -103,23 +103,23 @@ extern "C"
   extern Stringprep_profiles stringprep_profiles[];
 
 /* Profiles */
-  extern Stringprep_table_element stringprep_generic_A_1[];
-  extern Stringprep_table_element stringprep_generic_B_1[];
-  extern Stringprep_table_element stringprep_generic_B_2[];
-  extern Stringprep_table_element stringprep_generic_B_3[];
-  extern Stringprep_table_element stringprep_generic_C_1_1[];
-  extern Stringprep_table_element stringprep_generic_C_1_2[];
-  extern Stringprep_table_element stringprep_generic_C_2_1[];
-  extern Stringprep_table_element stringprep_generic_C_2_2[];
-  extern Stringprep_table_element stringprep_generic_C_3[];
-  extern Stringprep_table_element stringprep_generic_C_4[];
-  extern Stringprep_table_element stringprep_generic_C_5[];
-  extern Stringprep_table_element stringprep_generic_C_6[];
-  extern Stringprep_table_element stringprep_generic_C_7[];
-  extern Stringprep_table_element stringprep_generic_C_8[];
-  extern Stringprep_table_element stringprep_generic_C_9[];
-  extern Stringprep_table_element stringprep_generic_D_1[];
-  extern Stringprep_table_element stringprep_generic_D_2[];
+  extern Stringprep_table_element stringprep_rfc3454_A_1[];
+  extern Stringprep_table_element stringprep_rfc3454_B_1[];
+  extern Stringprep_table_element stringprep_rfc3454_B_2[];
+  extern Stringprep_table_element stringprep_rfc3454_B_3[];
+  extern Stringprep_table_element stringprep_rfc3454_C_1_1[];
+  extern Stringprep_table_element stringprep_rfc3454_C_1_2[];
+  extern Stringprep_table_element stringprep_rfc3454_C_2_1[];
+  extern Stringprep_table_element stringprep_rfc3454_C_2_2[];
+  extern Stringprep_table_element stringprep_rfc3454_C_3[];
+  extern Stringprep_table_element stringprep_rfc3454_C_4[];
+  extern Stringprep_table_element stringprep_rfc3454_C_5[];
+  extern Stringprep_table_element stringprep_rfc3454_C_6[];
+  extern Stringprep_table_element stringprep_rfc3454_C_7[];
+  extern Stringprep_table_element stringprep_rfc3454_C_8[];
+  extern Stringprep_table_element stringprep_rfc3454_C_9[];
+  extern Stringprep_table_element stringprep_rfc3454_D_1[];
+  extern Stringprep_table_element stringprep_rfc3454_D_2[];
 
   /* Generic (for debugging) */
 
@@ -173,15 +173,14 @@ extern "C"
 
   /* API */
 
-  extern enum Stringprep_rc
-    stringprep (char *in, size_t maxlen,
-		enum Stringprep_profile_flags flags,
-		Stringprep_profile *profile);
+  extern int stringprep (char *in, size_t maxlen,
+			 Stringprep_profile_flags flags,
+			 Stringprep_profile * profile);
 
-  extern enum Stringprep_rc
-    stringprep_profile (char *in,
-			char **out,
-			char *profile, enum Stringprep_profile_flags flags);
+  extern int stringprep_profile (char *in,
+				 char **out,
+				 char *profile,
+				 Stringprep_profile_flags flags);
 
   extern const char *stringprep_check_version (const char *req_version);
 
